@@ -3,53 +3,63 @@ use Mojo::Base 'Mojolicious::Plugin';
 use Mojo::File qw(path);
 use Mojolicious::Types;
 use Mojo::Path;
-use Mojo::Util qw(encode);
+#~ use Mojo::Util qw(decode);
 
-our $VERSION = '0.056';
 my $PKG = __PACKAGE__;
 
 has [qw(app config)];
-has root_url => sub { Mojo::Path->new(encode('UTF-8', shift->config->{root_url}))->leading_slash(1)->trailing_slash(1) };
+has root_url => sub { Mojo::Path->new(shift->config->{root_url})->leading_slash(1)->trailing_slash(1) };
 has root_dir => sub { Mojo::Path->new(shift->config->{root_dir} // '.')->trailing_slash(1) };
 has admin_pass => sub { shift->config->{admin_pass} };
+has access => sub { shift->config->{access} };
 has public_uploads => sub { !! shift->config->{public_uploads} };
 has render_dir =>  sub { shift->config->{render_dir} };
 has dir_index => sub { shift->config->{dir_index} // [qw(README.md INDEX.md README.pod INDEX.pod)] };
 has render_pod =>  sub { shift->config->{render_pod} };
 has render_markdown =>  sub { shift->config->{render_markdown} };
 has markdown_pkg => sub { shift->config->{markdown_pkg} // 'Text::Markdown::Hoedown' };
+has templates_dir => sub { shift->config->{templates_dir} };
 has markdown => sub {# parser object
    __internal__::Markdown->new(shift->markdown_pkg);
 };
-has is_markdown => sub { qr{[.]m(?:d(?:own)?|kdn?|arkdown)$}i };
-has is_pod => sub { qr{[.]p(?:od|m|l)$} };
+has re_markdown => sub { qr{[.]m(?:d(?:own)?|kdn?|arkdown)$}i };
+has re_pod => sub { qr{[.]p(?:od|m|l)$} };
 has mime => sub { Mojolicious::Types->new };
 
-sub register {
+sub register {# none magic
   my ($self, $app, $args) = @_;
   $self->config($args);
   $self->app($app);
   
+  my $push_class = "$PKG\::Templates";
+  my $push_path = path(__FILE__)->sibling('StaticShare')->child('static');
+  
   require Mojolicious::Plugin::StaticShare::Templates
-    and push @{$app->renderer->classes}, "$PKG\::Templates"
-    and push @{$app->static->paths}, path(__FILE__)->sibling('StaticShare')->child('static') 
+    and push @{$app->renderer->classes}, grep($_ eq $push_class, @{$app->renderer->classes}) ? () : $push_class
+    and push @{$app->static->paths}, grep($_ eq $push_path, @{$app->static->paths}) ? () : $push_path
     unless ($self->render_dir // '') eq 0
           && ($self->render_markdown // '') eq 0;
+  push @{$app->renderer->paths}, ref $self->templates_dir ? @{$self->templates_dir} : $self->templates_dir
+    if $self->templates_dir;
   
   my $route = $self->root_url->clone->merge('*pth');#"$args->{root_url}/*pth";
   my $r = $app->routes;
-  $r->get($self->root_url->to_route)->to(namespace=>$PKG, controller=>"Controller", action=>'get', pth=>'', plugin=>$self)->name("$PKG ROOT");
-  $r->post($self->root_url->to_route)->to(namespace=>$PKG, controller=>"Controller", action=>'post', pth=>'', plugin=>$self)->name("$PKG ROOT POST");
-  $r->get($route->to_route)->to(namespace=>$PKG, controller=>"Controller", action=>'get', plugin=>$self )->name("$PKG GET");
-  $r->post($route->to_route)->to(namespace=>$PKG, controller=>"Controller", action=>'post', plugin=>$self )->name("$PKG POST");
+  $r->get($self->root_url->to_route)->to(namespace=>$PKG, controller=>"Controller", action=>'get', pth=>'', plugin=>$self);#->name("$PKG ROOT GET");
+  $r->post($self->root_url->to_route)->to(namespace=>$PKG, controller=>"Controller", action=>'post', pth=>'', plugin=>$self);#->name("$PKG ROOT POST");
+  $r->get($route->to_route)->to(namespace=>$PKG, controller=>"Controller", action=>'get', plugin=>$self );#->name("$PKG GET");
+  $r->post($route->to_route)->to(namespace=>$PKG, controller=>"Controller", action=>'post', plugin=>$self );#->name("$PKG POST");
+  
+  path($self->config->{root_dir})->make_path
+    unless !$self->config->{root_dir} || -e $self->config->{root_dir};
 
-  $app->helper(i18n => sub { &i18n(@_) });
+  $app->helper(i18n => \&i18n);
+  #~ $app->helper(StaticShareIsAdmin => sub { $self->is_admin(@_) });
   
   #POD
   $self->app->plugin(PODRenderer => {no_perldoc => 1})
     unless $self->app->renderer->helpers->{'pod_to_html'} && ($self->render_pod // '') eq 0 ;
   
-  return $app;
+  return ($app, $self);
 }
 
 my %loc = (
@@ -60,6 +70,7 @@ my %loc = (
     'Permission denied'=>"Нет доступа",
     'Cant open directory'=>"Нет доступа в папку",
     'Share'=>'Обзор',
+    'Edit'=>'Редактировать',
     'Index of'=>'Содержание',
     'Dirs'=>'Папки',
     'Files'=>'Файлы',
@@ -79,6 +90,8 @@ my %loc = (
     'Confirm to delete these files'=>"Подтвердите удаление этих файлов",
      'Confirm to delete these dirs'=>"Подтвердите удаление этих папок", 
     'I AM SURE'=>"ДА",
+    'Save'=> 'Сохранить',
+    'Success saved' => "Успешно сохранено",
   },
 );
 sub i18n {# helper
@@ -98,6 +111,18 @@ sub i18n {# helper
   return $str;
 }
 
+sub is_admin {# as helper
+  my ($self, $c) = @_;
+  return 
+    unless my $pass = $self->admin_pass;
+  my $sess = $c->session;
+  $sess->{StaticShare}{admin} = 1
+    if $c->param('admin') && $c->param('admin') eq $pass;
+  return $sess->{StaticShare} && $sess->{StaticShare}{admin};
+}
+
+
+
 ##############################################
 package __internal__::Markdown;
 sub new {
@@ -116,7 +141,7 @@ sub new {
 
 sub parse { my $self = shift; no strict 'refs'; ($self->{pkg}.'::markdown')->(@_); }
 
-1;
+our $VERSION = '0.059';
 =pod
 
 =encoding utf8
@@ -133,12 +158,12 @@ Mojolicious::Plugin::StaticShare - browse, upload, copy, move, delete static fil
 
 =head1 VERSION
 
-0.056
+0.059
 
 =head1 SYNOPSIS
 
   # Mojolicious
-  $self->plugin('StaticShare', <options>);
+  $app->plugin('StaticShare', <options>);
 
   # Mojolicious::Lite
   plugin 'StaticShare', <options>;
@@ -146,10 +171,11 @@ Mojolicious::Plugin::StaticShare - browse, upload, copy, move, delete static fil
   # oneliner
   $ perl -MMojolicious::Lite -E 'plugin("StaticShare", root_url=>"/my/share",)->secrets([rand])->start' daemon
 
+L</MULTI-PLUGIN> also.
 
 =head1 DESCRIPTION
 
-This plugin for share static files/dirs and has public and admin functionality:
+This plugin allow to share static files/dirs/markdown and has public and admin functionality:
 
 =head2 Public interface
 
@@ -157,7 +183,7 @@ Can browse and upload files if name not exists.
 
 =head2 Admin interface
 
-Can copy, move, delete files/dirs.
+Can copy, move, delete, rename and edit content of files/dirs.
 
 Append param C<< admin=<admin_pass> option >> to any url inside B<root_url> requests (see below).
 
@@ -223,7 +249,16 @@ List of hashrefs (C<name, size, mtime> keys) files. Not sorted.
 
 =head4 index
 
-Filename for markdown or pod rendering in page below dirs and files.
+Filename for markdown or pod rendering in page below the column dirs and column files.
+
+=head2 templates_dir
+
+String or arrayref strings. Simply C<< push @{$app->renderer->paths}, <templates_dir>; >>. None defaults.
+
+Mainly needs for layouting markdown. When you set this option then you can define layout inside markdown/pod files like syntax:
+
+  % layouts/foo.html.ep
+  # Foo header
 
 =head2 render_markdown
 
@@ -264,26 +299,26 @@ Boolean to disable/enable uploads for public users. Defaults to undef (disable).
 
   public_uploads=>1, # enable
 
-=head1 UTF-8
-
-Everywhere  and everything: module, files, content.
-
-=head1 WINDOWS OS
-
-It was not tested but I hope you dont worry and have happy.
-
 =head1 Extended markdown & pod
 
-You can place attributes like id, classnames and css-style rules to markup elements as below.
+You can place attributes like:
+
+=head2 id (# as prefix)
+
+=head2 classnames (dot as prefix and separator)
+
+=head2 css-style rules (key:value; colon separator and semicolon terminator)
+
+to markup elements as below.
 
 In markdown:
 
-  # {.class1 .class2 padding: 0 0.5rem;} Header 1
+  # {#foo123 .class1 .class2 padding: 0 0.5rem;} Header 1
   {.brown-text} brown paragraph text ...
 
 In pod:
 
-  =head2 {.class1 .blue-text border-bottom: 1px dotted;} Header 2
+  =head2 {.class1.blue-text border-bottom: 1px dotted;} Header 2
   
   {.red-text} red color text...
 
@@ -298,6 +333,28 @@ L<Mojolicious::Plugin> and implements the following new ones.
 
 Register plugin in L<Mojolicious> application.
 
+=head1 MULTI PLUGIN
+
+A possible:
+
+  # Mojolicious
+  $app->plugin('StaticShare', <options-1>)
+           ->plugin('StaticShare', <options-2>); # and so on ...
+  
+  # Mojolicious::Lite
+  app->config(...)
+         ->plugin('StaticShare', <options-1>)
+         ->plugin('StaticShare', <options-2>) # and so on ...
+         ...
+
+=head1 UTF-8
+
+Everywhere  and everything: module, files, content.
+
+=head1 WINDOWS OS
+
+It was not tested but I hope you dont worry and have happy.
+
 =head1 SEE ALSO
 
 L<Mojolicious::Plugin::Directory>
