@@ -45,6 +45,9 @@ Template for render 404.
 
 Template for render 500.
 
+=head2 Mojolicious-Plugin-StaticShare/edit.html.ep
+
+File content editor (with ace.js)
 
 =cut
 1;
@@ -67,9 +70,9 @@ __DATA__
 
 <link href="/static-share/css/main.css" rel="stylesheet">
 
-% if (stash('pod')) {
-<style>
+<style type="text/css" media="screen">
 
+% if (stash('pod')) {
 pre {
   background-color: #fafafa;
   border: 1px solid #c1c1c1;
@@ -85,9 +88,9 @@ pre {
   padding: 0.3em;
 }
 
-</style>
 % }
 
+</style>
 
 <meta name="app:name" content="<%= stash('app:name') // 'Mojolicious::Plugin::StaticShare' %>">
 %#<meta name="app:version" content="<%= stash('app:version') // 0.01 %>">
@@ -101,14 +104,17 @@ pre {
 <main><div class="container clearfix"><%= stash('content') || content %></div></main>
 
 <script src="/mojo/jquery/jquery.js"></script>
-%#<script src="/js/dmuploader.min.js"></script>
 <script src="/static-share/js/jquery.ui.widget.js"></script>
 <script src="/static-share/js/jquery.fileupload.js"></script>
 <script src="/static-share/js/velocity.min.js"></script>
 <script src="/static-share/js/modal.js"></script>
-%#<script src="/static-share/js/svg.js"></script>
+<script src="/static-share/js/dropdown.js"></script>
 <script src="/static-share/js/main.js"></script>
 
+% if (param('edit')) {
+<script src="/static-share/js/ace.js" type="text/javascript" charset="utf-8"></script>
+% }
+
 %= javascript begin
   ///console.log('Доброго всем!! ALL GLORY TO GLORIA');
 % end
@@ -119,15 +125,15 @@ pre {
 @@ Mojolicious-Plugin-StaticShare/dir.html.ep
 % layout 'Mojolicious-Plugin-StaticShare/main';
 
-<div class="row">
-% if (@$dirs || $c->admin) {
+<div class="row show-on-ready" style="display:none;"><%#= @$dirs || @$files ? '' : 'style="min-height: calc(80vh);" ' %>
+% if (@$dirs || $c->is_admin) {
 <div class="dirs-col col s6">
 
-% if ($c->admin) {
-<div class="right btn-panel" style="padding:1.2rem 0;">
-  <a href="javascript:" class="hide renames"><svg xmlns="http://www.w3.org/2000/svg" class="icon icon15 black-fill"  viewBox="0 0 26 26"><use xlink:href="/static-share/fonts/icons.svg#rename" /></svg></a>
-  <a href="javascript:" class="hide del-dirs"><svg xmlns="http://www.w3.org/2000/svg" class="icon icon15 red-fill fill-lighten-1" viewBox="0 0 50 50"><use xlink:href="/static-share/fonts/icons.svg#dir-delete" /></svg></a>
-  <a id="add-dir" href="javascript:" class="btn-flat00" style="display:inline !important;">
+% if ($c->is_admin) {
+<div class="chip card lime lighten-5 btn-panel" style="left:0;">
+  <a href="javascript:" class="block btn-flat hide renames" style="padding:0 0.5rem;"><svg xmlns="http://www.w3.org/2000/svg" class="icon icon15 black-fill"  viewBox="0 0 26 26"><use xlink:href="/static-share/fonts/icons.svg#rename" /></svg></a>
+  <a href="javascript:" class="block btn-flat hide del-dirs" style="padding:0 0.5rem;"><svg xmlns="http://www.w3.org/2000/svg" class="icon icon15 red-fill fill-lighten-1" viewBox="0 0 50 50"><use xlink:href="/static-share/fonts/icons.svg#dir-delete" /></svg></a>
+  <a id="add-dir" href="javascript:" class="block btn-flat" style="padding:0 0.5rem;">
     <svg xmlns="http://www.w3.org/2000/svg" class="icon icon15 lime-fill fill-darken-4" viewBox="0 0 50 50"><use xlink:href="/static-share/fonts/icons.svg#add-dir" /></svg>
     <!--span class="lime-text text-darken-4"><%= i18n 'Add dir' %></span-->
   </a>
@@ -135,19 +141,19 @@ pre {
 
 % }
 
-<h2 class="lime-text text-darken-4">
+<h2 class="lime-text text-darken-4 center">
 %#  <svg xmlns="http://www.w3.org/2000/svg" class="icon icon15 lime-fill fill-darken-4"  viewBox="0 0 30 30"><use xlink:href="/static-share/fonts/icons.svg#folder" /></svg>
 %# <%= i18n 'Down' %>
   <svg xmlns="http://www.w3.org/2000/svg" class="icon icon15 lime-fill fill-darken-4" viewBox="0 0 50 50"><use xlink:href="/static-share/fonts/icons.svg#down-right-round" /></svg>
   <span class=""><%= i18n 'Dirs' %></span>
-  <span class="chip lime lighten-5" style=""><%= scalar @$dirs %></span>
+  <sup class="circle lime lighten-5" style="padding:0.3rem;"><%= scalar @$dirs %></sup>
 </h2>
 
 <div class="progress progress-dir white" style="margin:0; padding:0;">
     <div class="determinate lime" style="width: 0%"></div>
 </div>
 
-<table class="dirs" style="border: 1px solid #e0e0e0;">
+<table class="dirs card" style="border: 1px solid #e0e0e0;">
   <thead class="hide">
     <tr class="new-dir lime darken-4" style="border-bottom: 1px solid #e0e0e0;"><!-- template new folder -->
       <td style="width:1%;">
@@ -190,7 +196,7 @@ pre {
         </a>
       </td>
       <td class="chb" style="width:1%;">
-% if ($c->admin) { # delete dir
+% if ($c->is_admin) { # delete dir
           <input type="checkbox" name="dir-check" style="margin: 0 0.5rem;">
 % }
       </td>
@@ -202,14 +208,14 @@ pre {
 </div>
 % }
 
-% if (@$files || $c->admin || $c->public_uploads) {
+% if (@$files || $c->is_admin || $c->public_uploads) {
 <div class="files-col col s6">
 
-% if ($c->admin || $c->public_uploads) {
-<div class="right btn-panel" style="padding:1.2rem 0;">
-  <a href="javascript:" class="hide renames"><svg xmlns="http://www.w3.org/2000/svg" class="icon icon15 black-fill"  viewBox="0 0 26 26"><use xlink:href="/static-share/fonts/icons.svg#rename" /></svg></a>
-  <a href="javascript:" class="hide del-files"><svg xmlns="http://www.w3.org/2000/svg" class="icon icon15 red-fill fill-lighten-1"  viewBox="0 0 26 26"><use xlink:href="/static-share/fonts/icons.svg#file-delete" /></svg></a>
-  <label for="fileupload" class="btn-flat000">
+% if ($c->is_admin || $c->public_uploads) {
+<div class="chip card light-blue lighten-5 btn-panel" style="right:0;">
+  <a href="javascript:" class="block btn-flat hide renames" style="padding:0 0.5rem;"><svg xmlns="http://www.w3.org/2000/svg" class="icon icon15 black-fill"  viewBox="0 0 26 26"><use xlink:href="/static-share/fonts/icons.svg#rename" /></svg></a>
+  <a href="javascript:" class="block btn-flat hide del-files" style="padding:0 0.5rem;"><svg xmlns="http://www.w3.org/2000/svg" class="icon icon15 red-fill fill-lighten-1"  viewBox="0 0 26 26"><use xlink:href="/static-share/fonts/icons.svg#file-delete" /></svg></a>
+  <label for="fileupload" class="block btn-flat" style="padding:0 0.5rem;">
     <svg xmlns="http://www.w3.org/2000/svg" class="icon icon15 light-blue-fill fill-darken-1" viewBox="0 0 26 26"><use xlink:href="/static-share/fonts/icons.svg#add-item" /></svg>
     <!--span class="blue-text"><%= i18n 'Add uploads'%></span-->
   </label>
@@ -219,16 +225,16 @@ pre {
 
 % }
 
-<h2 class="light-blue-text text-darken-2">
+<h2 class="light-blue-text text-darken-2 center">
   <%= i18n 'Files'%>
-  <span class="chip light-blue lighten-5" style=""><%= scalar @$files %></span>
+  <sup class="circle light-blue lighten-5" style="padding:0.3rem;"><%= scalar @$files %></sup>
 </h2>
 
 <div class="progress progress-file white" style="margin:0; padding:0;">
     <div class="determinate blue" style="width: 0%"></div>
 </div>
 
-<table class="striped files light-blue lighten-5" style="border: 1px solid #e0e0e0;">
+<table class="striped files light-blue lighten-5 card" style="border: 1px solid #e0e0e0;">
 %#<thead>
 %#  <tr>
 %#    <th class="name"><%= i18n 'Name'%></th>
@@ -263,7 +269,7 @@ pre {
   % my $href = $url_path->clone->merge($file->{name})->to_route;
   <tr class="" style="border-bottom: 1px solid #e0e0e0;">
     <td class="chb" style="width:1%;">
-% if ($c->admin) {
+% if ($c->is_admin) {
       <input type="checkbox" name="file-check"  class="" style="margin:0 0.5rem;">
 % }
     </td>
@@ -275,6 +281,11 @@ pre {
     </td>
     <td class="action" style="width:1%;">
       <a href="<%= $href %>?attachment=1" class="file-download" style="padding:0.1rem;"><svg xmlns="http://www.w3.org/2000/svg" class="icon icon12 light-blue-fill fill-darken-1" style000="height:1.2rem;" viewBox="0 0 26 26"><use xlink:href="/static-share/fonts/icons.svg#download" /></svg></a>
+      
+% if ($c->is_admin) {
+      <a href="<%= $href %>?edit=1" class="file-edit hide" style="padding:0.1rem;"><svg xmlns="http://www.w3.org/2000/svg" class="icon icon12 light-blue-fill fill-darken-1" style000="height:1.2rem;" viewBox="0 0 252 252"><use xlink:href="/static-share/fonts/icons.svg#edit-file" /></svg></a>
+% }
+
       <a href="javascript:" _href="<%= $href %>" class="file-rename hide" style="padding:0.1rem;"><svg class="icon icon12" viewBox="0 0 26 26"><use xlink:href="/static-share/fonts/icons.svg#upload" /></svg></a>
 
     </td>
@@ -291,16 +302,38 @@ pre {
 </div><!-- row -->
 
 % if (stash 'index') {
-  <div class="right-align grey-text"><%= stash 'index' %></div>
+  <h4 class="right-align grey-text" title="<%= i18n 'below to the end' %>"><%= stash 'index' %></h4>
+% }
+% if (stash('markdown') || stash('pod')) {
+  <div class="index-file show-on-ready" style="display:none;"><%== stash('markdown') || stash('pod') || '' %></div>
 % }
-<div class="index"><%== stash('markdown') || stash('pod') || '' %></div>
 
 %= include 'Mojolicious-Plugin-StaticShare/confirm-modal';
 
+<div id="footer">
+  Powered by
+  <a href="http://mojolicious.org">
+    <picture>
+      <img class="logo" src="/mojo/logo-black.png" srcset="/mojo/logo-black-2x.png 2x" alt="Mojolicious logo">
+    </picture>
+  </a>
+</div>
+
 @@ Mojolicious-Plugin-StaticShare/header.html.ep
 
 <header class="container clearfix">
-<h1><%= i18n 'Index of'%>
+
+% if ($c->is_admin && $c->plugin->config->{admin_nav}) {
+  <%== ref($c->plugin->config->{admin_nav}) eq 'CODE' ? $c->plugin->config->{admin_nav}($c) : $c->plugin->config->{admin_nav} %>
+% }
+
+<h1>
+  % if (param 'edit') {
+  <%= i18n 'Edit'%>
+  % } else {
+  <%= i18n 'Index of'%>
+  % }
+
 % unless (@{$url_path->parts}) {
   <a href="<%= $url_path %>" class="chip grey-text grey lighten-4"><%= i18n 'root' %></a>
 % }
@@ -311,7 +344,7 @@ pre {
 % }
 
 % if ($c->plugin->root_url->to_route ne $url_path->to_route) {
-  <a href="<%= $url_path->clone->trailing_slash(0)->to_dir %>" class="btn-flat000 " style="white-space:nowrap;">
+  <a href="<%= $url_path->clone->trailing_slash(0)->to_dir %>" class="btn-flat000 chip right nowrap" style="">
     <svg xmlns="http://www.w3.org/2000/svg" class="icon icon15 maroon-fill" viewBox="0 0 50 50"><use xlink:href="/static-share/fonts/icons.svg#up-left-round" /></svg>
     <span class="maroon-text"><%= i18n 'Up'%></span>
   </a>
@@ -350,8 +383,8 @@ pre {
 <!-- Modal Structure -->
 <div id="confirm-modal" class="modal bottom-sheet modal-fixed-footer">
   <div class="modal-header hide">
-    <h2 class="red-text del-files"><span><%= i18n 'Confirm to delete these files' %></span><span class="chip red lighten-4"></span></h2>
-    <h2 class="red-text del-dirs"><span><%= i18n 'Confirm to delete these dirs' %></span><span class="chip red lighten-4"></span></h2>
+    <h2 class="red-text del-files"><span><%= i18n 'Confirm to delete these files' %></span><sup class="circle red lighten-4" style="padding:0.3rem;"></sup></h2>
+    <h2 class="red-text del-dirs"><span><%= i18n 'Confirm to delete these dirs' %></span><sup class="circle red lighten-4" style="padding:0.3rem;"></sup></h2>
     <h2 class="red-text foo">Foo header</h2>
   </div>
   <div class="modal-content"></div>
@@ -362,3 +395,22 @@ pre {
     </a>
   </div>
 </div>
+
+@@ Mojolicious-Plugin-StaticShare/edit.html.ep
+% layout 'Mojolicious-Plugin-StaticShare/main';
+
+<div class="show-on-ready" style="display:none;">
+  <pre id="editor"><%= $edit %></pre>
+</div>
+
+
+<div class="right-align action">
+  <span class="green-text success hide"><%= i18n 'Success saved'%></span>
+  <span class="red-text fail hide"><%= i18n 'Success saved'%></span>
+  
+  <a href="javascript:" _href="<%= $url_path->clone->trailing_slash(0)->to_route %>" class="save btn-flat blue-text">
+    <svg xmlns="http://www.w3.org/2000/svg" class="icon icon15 blue-fill" viewBox="0 0 24 24"><use xlink:href="/static-share/fonts/icons.svg#save" /></svg>
+    <span><%= i18n 'Save'%></span>
+  </a>
+  
+</div>
\ No newline at end of file
